@@ -2,6 +2,8 @@
 #include <cstring>
 #include <cstdio>
 #include <cstdint>
+#include "debug.h"
+#include "ggtag.h"
 #include "utils.h"
 #include "protocol.h"
 #include "GUI_Paint.h"
@@ -243,9 +245,10 @@ struct BitBuffer {
         }
         return true;
     }
-    bool addCmd(const RectCmd &cmd)
+    bool addCmd(const RectCmd &cmd, bool fill)
     {
-        if (!addBits(RECT_CMD, CMD_BITS)) {
+        int cmd_bits = fill ? FILL_RECT_CMD : RECT_CMD;
+        if (!addBits(cmd_bits, CMD_BITS)) {
             return false;
         }
         if (!addBits(cmd.x, X_BITS)) {
@@ -262,9 +265,10 @@ struct BitBuffer {
         }
         return true;
     }
-    bool addCmd(const CircleCmd &cmd)
+    bool addCmd(const CircleCmd &cmd, bool fill)
     {
-        if (!addBits(CIRCLE_CMD, CMD_BITS)) {
+        int cmd_bits = fill ? FILL_CIRCLE_CMD : CIRCLE_CMD;
+        if (!addBits(cmd_bits, CMD_BITS)) {
             return false;
         }
         if (!addBits(cmd.x, X_BITS)) {
@@ -345,9 +349,15 @@ bool parseCommand(const char *input, int *cmd, int *curr_offset)
         case 'r':
             *cmd = RECT_CMD;
             break;
+        case 'R':
+            *cmd = FILL_RECT_CMD;
+            break;
         case 'c':
             *cmd = CIRCLE_CMD;
             break;
+        case 'C':
+            *cmd = FILL_CIRCLE_CMD;
+            break;
         case 'l':
             *cmd = LINE_CMD;
             break;
@@ -750,22 +760,24 @@ bool parse(const char *input, BitBuffer *buf, int *curr_offset)
             }
             break;
         case RECT_CMD:
+        case FILL_RECT_CMD:
             RectCmd rect_cmd;
             if (!parseRectCmd(input, &rect_cmd, &offset)) {
                 sprintf(lastError, "Failed to parse Rect command");
                 return false;
             }
-            if (!buf->addCmd(rect_cmd)) {
+            if (!buf->addCmd(rect_cmd, cmd == FILL_RECT_CMD)) {
                 return false;
             }
             break;
         case CIRCLE_CMD:
+        case FILL_CIRCLE_CMD:
             CircleCmd circle_cmd;
             if (!parseCircleCmd(input, &circle_cmd, &offset)) {
                 sprintf(lastError, "Failed to parse Circle command");
                 return false;
             }
-            if (!buf->addCmd(circle_cmd)) {
+            if (!buf->addCmd(circle_cmd, cmd == FILL_CIRCLE_CMD)) {
                 return false;
             }
             break;
@@ -825,70 +837,124 @@ bool parse(const char *input, BitBuffer *buf, int *curr_offset)
     return parse(input, buf, &offset);
 }
 
-extern "C" {
-    // Allocates a buffer and encodes the input string into it. The buffer length is returned in 'length'.
-    // Caller is responsible for freeing the buffer.
-    uint8_t* encode(const char *input, int *length)
-    {
-        BitBuffer buf;
-        int offset = 0;
-        if (parse(input, &buf, &offset)) {
-            // clear the error message if parsing was successful
-            sprintf(lastError, "OK");
-        }
-        if (buf.size() == 0) {
-            return 0;
-        }
-        //buf.dumpBytes();
-        uint8_t *ret = (uint8_t*) calloc(buf.size()+2, 1);
-        if (!ret) {
-            return 0;
-        }
-        // the first two byte are the total length of the encoded data
-        ret[0] = buf.size() / 256;
-        ret[1] = buf.size() % 256;
-        // followed by the encoded data
-        memcpy(ret+2, buf.buffer, buf.size());
-        *length = buf.size() + 2;
-        return ret;
+// Allocates a buffer and encodes the input string into it. The buffer length is returned in 'length'.
+// Caller is responsible for freeing the buffer.
+uint8_t* encode(const char *input, int *length)
+{
+    BitBuffer buf;
+    int offset = 0;
+    if (parse(input, &buf, &offset)) {
+        // clear the error message if parsing was successful
+        sprintf(lastError, "OK");
     }
+    if (buf.size() == 0) {
+        return 0;
+    }
+    //buf.dumpBytes();
+    uint8_t *ret = (uint8_t*) calloc(buf.size()+2, 1);
+    if (!ret) {
+        return 0;
+    }
+    // the first two byte are the total length of the encoded data
+    ret[0] = buf.size() / 256;
+    ret[1] = buf.size() % 256;
+    // followed by the encoded data
+    memcpy(ret+2, buf.buffer, buf.size());
+    *length = buf.size() + 2;
+    return ret;
+}
 
-    // Returns the last error message from the parser.
-    // The memory is owned by the parser and should not be freed.
-    char* getLastError()
-    {
-        return lastError;
-    }
+// Returns the last error message from the parser.
+// The memory is owned by the parser and should not be freed.
+char* getLastError()
+{
+    return lastError;
+}
 
-    // Allocates a bitmap with dimensions [ceil(width/8), height] and renders the specified input string to it.
-    // Caller is responsible for freeing the bitmap.
-    uint8_t* render(const char *input, int width, int height)
-    {
-        int offset = 0;
-        BitBuffer buf;
-        if (parse(input, &buf, &offset)) {
-            // clear the error message if parsing was successful
-            sprintf(lastError, "OK");
-        }
-        if (buf.size() == 0) {
-            return 0;
-        }
-        printf("Bit buffer length: %d\n", buf.ind);
-        int w = width / 8;
-        if (width % 8 != 0) {
-            w += 1;
-        }
-        int total = w * height;
-        uint8_t *bitmap = (uint8_t*) malloc(total);
-        if (!bitmap) {
-            return 0;
-        }
-        memset(bitmap, 0, total);
-        Paint_NewImage(bitmap, width, height, 0, WHITE);
-        Paint_Clear(WHITE);
-        renderBits(buf.buffer, buf.ind);
-        return bitmap;
+// Allocates a bitmap with dimensions [ceil(width/8), height] and renders the specified input string to it.
+// Caller is responsible for freeing the bitmap.
+uint8_t* render(const char *input, int width, int height)
+{
+    if (!input || width <= 0 || height <= 0) {
+        return 0;
     }
+    int offset = 0;
+    BitBuffer buf;
+    if (parse(input, &buf, &offset)) {
+        // clear the error message if parsing was successful
+        sprintf(lastError, "OK");
+    }
+    if (buf.size() == 0) {
+        return 0;
+    }
+    debug("Bit buffer length: %d\n", buf.ind);
+    int w = width / 8;
+    if (width % 8 != 0) {
+        w += 1;
+    }
+    int total = w * height;
+    uint8_t *bitmap = (uint8_t*) malloc(total);
+    if (!bitmap) {
+        return 0;
+    }
+    memset(bitmap, 0, total);
+    Paint_NewImage(bitmap, width, height, 0, WHITE);
+    Paint_Clear(WHITE);
+    renderBits(buf.buffer, buf.ind);
+    return bitmap;
+}
+
+// Allocates a bitmap with size ceil(width * height / 8) and performs dithering of the specified input image.
+// Caller is responsible for freeing the bitmap.
+uint8_t* dither(const uint8_t *rgba, int width, int height)
+{
+    if (!rgba || width <= 0 || height <= 0) {
+        return 0;
+    }
+    float *gray = (float*) malloc(width * height * sizeof(float));
+    if (!gray) {
+        return 0;
+    }
+    for (int i = 0; i < width * height; i++) {
+        gray[i] = 0.2126 * rgba[i*4] + 0.7152 * rgba[i*4+1] + 0.0722 * rgba[i*4+2];
+    }
+    for (int y = 0; y < height; y++) {
+        for (int x = 0; x < width; x++) {
+            float oldpixel = gray[y * width + x];
+            float newpixel = (oldpixel > 127) ? 255 : 0;
+            gray[y * width + x] = newpixel;
+            float quant_error = oldpixel - newpixel;
+            if (x < width - 1) {
+                gray[y * width + x + 1] += quant_error * 7.0 / 16.0;
+            }
+            if (x > 0 && y < height - 1) {
+                gray[(y + 1) * width + x - 1] += quant_error * 3.0 / 16.0;
+            }
+            if (y < height - 1) {
+                gray[(y + 1) * width + x] += quant_error * 5.0 / 16.0;
+            }
+            if (x < width - 1 && y < height - 1) {
+                gray[(y + 1) * width + x + 1] += quant_error * 1.0 / 16.0;
+            }
+        }
+    }
+    int length = width * height / 8;
+    if (width * height % 8 != 0) {
+        length += 1;
+    }
+    uint8_t *bitmap = (uint8_t*) malloc(length);
+    if (!bitmap) {
+        free(gray);
+        return 0;
+    }
+    memset(bitmap, 0, length);
+    for (int i = 0; i < width * height; i++) {
+        if (gray[i] < 127) {
+            bitmap[i / 8] |= 1 << (7 - i % 8);
+        }
+    }
+    free(gray);
+    return bitmap;
 }
 
 int main(int argc, char *argv[])
